; Sourcecode copied from Metaller (Blutrausch I2C)
;
; 100kHz Bustakt
; MT + MR
; Adresse vom LM75 = 1001001x ( 0=write / 1=read )
; PTR-Register fr die Temperatur = 0x00
;
; Vorgang (* bedeutet erledigt):
;  0. TWI initialisieren 
;  1. Startbedingung setzen
;  2. Slave-Write-Adresse senden
;  3. ACK vom Slave abfragen (wenn ok dann weiter mit 4., ansonsten ERROR)
;  4. PTR-Register auswhlen
;  5. ACK vom Slave abfragen (wenn ok dann weiter mit 6., ansonsten ERROR)
;  6. Stopbedingung setzen
;  7. warten
;  8. Startbedingung setzen
;  9. Slave-Write-Adresse senden
; 10. ACK vom Slave abfragen (wenn ok dann weiter mit 11., ansonsten ERROR)
; 11. umschalter auf Master-Reciver (MR)
; 12. Datenpaket 1 empfangen
; 13. Datenpaket 1 ausgeben (evtl. Komplement bilden)
; 14. Master ACK senden
; 15. Datenpaket 2 empfangen
; 16. Master NAK senden
; 17. Stopbedingung setzen
;

;Auf der Datenleitung SDA bedeutet ein high-Pegel (ca. 3-5V) eine logische 1 (Bitwert=1) ein low-Pegel (ca. 0V) eine logische Null (Bitwert=0). 
;Der Pegel auf SDA wird gendert, whrend die Taktleitung SCL low ist. SDA wird gelesen, whrend SCL high ist.
;Der Master (=PC) steuert SCL und SDA. Bevor der Slave sendet, mssen wir SDA auf high setzen. Der Slave sendet seine Daten (-Bits) ja, 
;indem er SDA auf Masse zieht oder high lsst.
;Im Folgenden ist beschrieben was passieren muss, um einen vollstndigen Temperaturwert zu lesen

;   1. Master sendet STOP-Bedingung
;      SCL auf high setzen, dann SDA auf high setzen. Beim ersten Durchlauf hat STOP den Sinn, eine definierte Ausgangssituation zu erzeugen.
;   2. Master sendet START-Bedingung
;      Erst SDA auf low setzen, dann SCL. Damit sind die angeschlossenen Gerte (unser LM75) lesebereit.
;   3. Master sendet Adress-Byte
;      Das Byte muss in unserem Fall binr so aussehen: 1001 0001. 1001 ist der unvernderliche erste Teil der Adresse jedes LM75. 
;      Die folgenden drei Bits bestimmen wir damit, wie wir die Leitungen A0/A1/A2 verbunden haben. Laut Schaltplan sind alle mit Masse verbunden, 
;      deshalb sind drei Nullen erforderlich.  Mit dem letzten Bit, sagen wir dem Slave, ob wir anschlieend lesen oder schreiben wollen. 
;      Wir wollen vom Slave lesen, also ist der Bitwert 1.
;      Das erste Bit gibt der Master sofort auf den Bus, indem er die SDA auf high setzt. Dann geht SCL auf high, anschlieend auf low und das 
;      nchste Bit kann bertragen werden. Das ganze wiederholt sich insgesamt acht mal.
;   4. Slave sendet ACKNOWLEDGE
;      Nachdem der Master SCL ein weiteres mal auf high gesetzt, hat knnen wir der Pegel von SDA lesen. Hat der Slave SDA auf low gezogen, 
;      hat er damit den Empfang des Bytes quittiert (bleibt die Leitung high, wird in LM75-I2C.BAS eine Variable hochgezhlt und angezeigt). 
;      Abschlieend setzt der Master SCL wieder auf low.
;   5. Slave sendet das erste Datenbyte
;      Dazu folgt acht mal: SCL auf high setzen, SDA lesen (wenn high, Bitwert addieren), dann SCL wieder auf low setzen. 
;      Das erste Bit hat den Wert 128, das zweite 64, das dritte 32 usw.
;   6. Master sendet ACKNOWLEDGE
;      SDA auf low, dann SCL auf high, anschlieend SCL wieder auf low. Damit quittiert der Master das Datenbyte und signalisiert Bereitschaft fr ein weiteres Byte.
;   7. Slave sendet das zweite Datenbyte
;      Hier passiert dasselbe wie unter 5. Wir bentigen jedoch nur das erste (hchstwertige) Bit. Diese stellt den 0,5C-Anteil dar. 
;      Die restlichen 7 Bits sind ohne Bedeutung.
;   8. Master sendet NO ACKNOWLEDGE
;      SDA auf high, SCL auf high, anschlieend auf low. Das bedeutet, dass der Master das Byte empfangen hat, jedoch keine weiteren Daten wnscht.
;   9. Master sendet STOP-Bedingung
;      SCL auf high setzen, dann SDA auf high setzen. Jetzt sind wir wieder da, wo wir hergekommen sind. 
;===========================================================================================================================================================================
;input:  R16 = 8 bit value 0 ... 255
;output: R18, R17, R16 = ASCII-digits

;bcd:
;        ldi     r18, -1 + '0'
;_bcd1:
;        inc     r18
;        subi    r16, 100
;        brcc    _bcd1
;
;        ldi     r17, 10 + '0'
;_bcd2:
;        dec     r17
;        subi    r16, -10
;        brcs    _bcd2
;        sbci    r16, -'0'
;        ret
;===============================================

;Im Pseudecode ist das etwa so:

;X: Originalzahl
;H: Hunderter
;Z: Zehner
;E: Einer


;H=0
;Z=0
;E=0
;Solange X>100
;  X=X-100
;  H=H+1
;Solange X>10
;  X=X-10
;  Z=Z+1
;E=X

;
